mathtools.NonreducedRatio
=========================

.. abjad-lineage:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio

.. autoclass:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.count
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.index
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__add__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__contains__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__getitem__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__getslice__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__hash__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__iter__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__len__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__mul__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__repr__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.NonreducedRatio.__rmul__
   :noindex:
